/*! \brief IPO
 * 
 * Implementation of a component
 *
 * File:   IPO.cpp
 * Author: Dieter Steuten
  * Licence: Apache 2.0
 *
 */

/* --- Includes --- */
#include "IPO.hpp"

/* --- CPP regular --- * /
IPO::IPO() {}
IPO::~IPO() {}*/

/* --- protected functionalities --- * /
bool IPO::P(bool startstop) { return startstop; }
void *IPO::O() { return nullptr; }
void IPO::I(void *irgendwas) {irgendwas = nullptr; }*/
